<?php

namespace Drupal\protected_download\StreamWrapper;

use Drupal\Core\Site\Settings;
use Drupal\Core\StreamWrapper\LocalStream;
use Drupal\Core\StreamWrapper\StreamWrapperInterface;
use Drupal\protected_download\LinkGeneratorInterface;

/**
 * Defines a Drupal protected (protected://) stream wrapper class.
 */
class ProtectedStream extends LocalStream {

  /**
   * {@inheritdoc}
   */
  public static function getType() {
    return StreamWrapperInterface::LOCAL_NORMAL;
  }

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return t('Protected files');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return t('Protected local files secured using a HMAC.');
  }

  /**
   * {@inheritdoc}
   */
  public function getDirectoryPath() {
    return Settings::get('protected_download_file_path_protected');
  }

  /**
   * {@inheritdoc}
   */
  public function getExternalUrl() {
    $linkGenerator = \Drupal::service(LinkGeneratorInterface::class);
    assert($linkGenerator instanceof LinkGeneratorInterface);
    return $linkGenerator->generate($this->uri)->setAbsolute()->toString();
  }

}
